﻿using Common.system;

using System;
using System.Configuration;
using System.Text;
using System.Text.RegularExpressions;

//using System.Text.RegularExpressions;
using System.Windows;
using System.Windows.Input;

using XHWK.WKTool.DAL;

namespace XHWK.WKTool
{
    /// <summary>
    /// LoginWindow.xaml 的交互逻辑
    /// </summary>
    public partial class LoginWindow : Window
    {
        /// <summary>
        /// 调用接口
        /// </summary>
        private readonly Interface @interface = new Interface();

        public LoginWindow()
        {
            InitializeComponent();

            Initialize();
        }

        public void Initialize()
        {
            if (FileToolsCommon.IsExistFile(APP.DataPath + "accountNumber.txt"))
            {
                string accountNumber = System.IO.File.ReadAllText(APP.DataPath + "accountNumber.txt", Encoding.Default);
                if (!string.IsNullOrWhiteSpace(accountNumber))
                {
                    txbAccountNumber.Text = accountNumber;
                    ckSaveName.IsChecked = true;
                }
            }
            DataContext = APP.PageContextData;
        }

        /// <summary>
        /// 关闭事件
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BtnDown_Click(object sender, RoutedEventArgs e)
        {
            txbAccountNumber.Text = string.Empty;
            pobPassword.Password = string.Empty;
            Hide();
        }

        /// <summary>
        /// 登录事件
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BtnStart_Click(object sender, RoutedEventArgs e)
        {
            #region 获取服务接口地址 --2021年7月9日赵耀

            if (APP.ServiceAddress == null)
            {
                MessageWindow.Show("首次使用需设置服务地址。");
                BtnServiceAddress_Click(null, null);
                return;
            }

            #endregion 获取服务接口地址 --2021年7月9日赵耀

            if (string.IsNullOrEmpty(txbAccountNumber.Text))
            {
                MessageWindow.Show("账号未输入");
                return;
            }
            if (txbAccountNumber.Text.Length > 16)
            {
                MessageWindow.Show("账号长度不能高于16位");
                return;
            }
            if (string.IsNullOrEmpty(pobPassword.Password))
            {
                MessageWindow.Show("密码未输入");
                return;
            }
            if (pobPassword.Password.Length > 16)
            {
                MessageWindow.Show("密码长度不能高于16位");
                return;
            }
            APP.myloading.Show();
            Login();
        }

        /// <summary>
        /// 登录
        /// </summary>
        private void Login()
        {
            string accountNumber = string.Empty;
            string password = string.Empty;
            Dispatcher.Invoke(new Action(() =>
            {
                accountNumber = txbAccountNumber.Text.Replace(" ", "").Trim();
                password = pobPassword.Password.Replace(" ", "").Trim();
            }));

            int code = @interface.Login(accountNumber, password);
            if (code == 0)
            {
                FileToolsCommon.CreateDirectory(APP.DataPath);
                string applicationData = APP.DataPath + "accountNumber.txt";
                if (ckSaveName.IsChecked == true)
                {
                    string accountNumbers = txbAccountNumber.Text;
                    System.IO.File.WriteAllText(applicationData, accountNumbers, Encoding.Default);//存放账号
                }
                else
                {
                    string accountNumbers = "";
                    System.IO.File.WriteAllText(applicationData, accountNumbers, Encoding.Default);//存放账号
                }

                APP.myloading.Hide();
                //UpdateSettingString("userName", txbAccountNumber.Text);
                APP.IsLoginType = true;
                txbAccountNumber.Text = string.Empty;
                pobPassword.Password = string.Empty;

                #region 下载头像

                string HeadpicPath = FileToolsCommon.GetFileAbsolutePath("/Data/" + APP.UserInfo.Username + ".png");
                if (!string.IsNullOrWhiteSpace(APP.UserInfo.Headpic))
                {
                    //FileToolsCommon.
                    @interface.DownloadAvatar(APP.UserInfo.Headpic, HeadpicPath);
                }

                #endregion 下载头像

                Hide();
            }
            else
            {
                APP.IsLoginType = false;
                APP.myloading.Hide();
                MessageWindow.Show(APP.ServerMsg);
            }
        }

        /// <summary>
        /// 记住账号
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void CkSaveName_Click(object sender, RoutedEventArgs e)
        {
        }

        /// <summary>
        /// 读取客户设置
        /// </summary>
        /// <param name="settingName"></param>
        /// <returns></returns>
        public static string GetSettingString(string settingName)
        {
            try
            {
                string settingString = ConfigurationManager.AppSettings[settingName].ToString();
                return settingString;
            }
            catch (Exception)
            {
                return null;
            }
        }

        /// <summary>
        /// 更新设置
        /// </summary>
        /// <param name="settingName"></param>
        /// <param name="valueName"></param>
        public static void UpdateSettingString(string settingName, string valueName)
        {
            Configuration config = ConfigurationManager.OpenExeConfiguration(ConfigurationUserLevel.None);

            if (ConfigurationManager.AppSettings[settingName] != null)
            {
                config.AppSettings.Settings.Remove(settingName);
            }
            config.AppSettings.Settings.Add(settingName, valueName);
            config.Save(ConfigurationSaveMode.Modified);
            ConfigurationManager.RefreshSection("appSettings");
        }

        /// <summary>
        /// 限制输入特殊字符
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void txbAccountNumber_PreviewTextInput(object sender, TextCompositionEventArgs e)
        {
            try
            {
                Regex re = new Regex("[^0-9\\-]+");
                Regex re1 = new Regex("[^A-Za-z\\-]+");
                if (!re.IsMatch(e.Text))
                {
                    e.Handled = re.IsMatch(e.Text);
                }
                else if (!re1.IsMatch(e.Text))
                {
                    e.Handled = re1.IsMatch(e.Text);
                }
                else
                {
                    e.Handled = true;
                }
            }
            catch (Exception)
            {
            }
        }

        private void Border_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            DragMove();
        }

        #region 服务地址

        /// <summary>
        /// 打开服务地址
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BtnServiceAddress_Click(object sender, RoutedEventArgs e)
        {
            GridLoginPage.Visibility = Visibility.Collapsed;
            GridServiceAddress.Visibility = Visibility.Visible;
        }

        /// <summary>
        /// 取消
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BtnCancel_Click(object sender, RoutedEventArgs e)
        {
            GridLoginPage.Visibility = Visibility.Visible;
            GridServiceAddress.Visibility = Visibility.Collapsed;
        }

        /// <summary>
        /// 服务地址设置
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BtnSetServiceAddress_Click(object sender, RoutedEventArgs e)
        {
            #region 获取服务地址 -- 2021年7月8日赵耀

            if (!string.IsNullOrWhiteSpace(TbxServiceAddress.Text))
            {
                if (@interface.GetServiceAddress(TbxServiceAddress.Text, out string Message))
                {
                    APP.SaveServiceAddressData();
                    APP.SwitchAddress();

                    MessageWindow.Show("设置成功！");
                    BtnCancel_Click(null, null);
                }
                else
                {
                    MessageWindow.Show(Message);
                    return;
                }
            }

            #endregion 获取服务地址 -- 2021年7月8日赵耀
        }

        #region 切换校内外

        /// <summary>
        /// 校外
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void RbnIsOutsideSchool_Checked(object sender, RoutedEventArgs e)
        {
            APP.IsOutsideSchool = true;
            FileToolsCommon.SetConfigValue("IsOutsideSchool", "1");
            if (APP.ServiceAddress != null)
            {
                APP.SwitchAddress();
            }
        }

        /// <summary>
        /// 校内
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void RbnSchool_Checked(object sender, RoutedEventArgs e)
        {
            APP.IsOutsideSchool = false;
            FileToolsCommon.SetConfigValue("IsOutsideSchool", "0");
            if (APP.ServiceAddress != null)
            {
                APP.SwitchAddress();
            }
        }

        #endregion 切换校内外

        #endregion 服务地址
    }
}